export const packageJson = {
    "name": "wechaty-puppet",
    "version": "1.21.3",
    "description": "Abstract Puppet for Wechaty",
    "type": "module",
    "exports": {
        ".": {
            "import": "./dist/esm/src/mods/mod.js",
            "require": "./dist/cjs/src/mods/mod.js"
        },
        "./filters": {
            "import": "./dist/esm/src/mods/filters.js",
            "require": "./dist/cjs/src/mods/filters.js"
        },
        "./helpers": {
            "import": "./dist/esm/src/mods/helpers.js",
            "require": "./dist/cjs/src/mods/helpers.js"
        },
        "./impls": {
            "import": "./dist/esm/src/mods/impls.js",
            "require": "./dist/cjs/src/mods/impls.js"
        },
        "./payloads": {
            "import": "./dist/esm/src/mods/payloads.js",
            "require": "./dist/cjs/src/mods/payloads.js"
        },
        "./types": {
            "import": "./dist/esm/src/mods/types.js",
            "require": "./dist/cjs/src/mods/types.js"
        }
    },
    "typesVersions": {
        "*": {
            "filters": [
                "./dist/esm/src/mods/filters.d.ts"
            ],
            "helpers": [
                "./dist/esm/src/mods/helpers.d.ts"
            ],
            "impls": [
                "./dist/esm/src/mods/impls.d.ts"
            ],
            "payloads": [
                "./dist/esm/src/mods/payloads.d.ts"
            ],
            "types": [
                "./dist/esm/src/mods/types.d.ts"
            ]
        }
    },
    "types": "./dist/esm/src/mods/mod.d.ts",
    "engines": {
        "node": ">=16",
        "npm": ">=7"
    },
    "scripts": {
        "clean": "shx rm -fr dist/*",
        "dist": "npm-run-all clean build dist:commonjs",
        "build": "tsc && tsc -p tsconfig.cjs.json",
        "dist:commonjs": "jq -n \"{ type: \\\"commonjs\\\" }\" > dist/cjs/package.json",
        "lint": "npm-run-all lint:es lint:ts lint:md",
        "lint:md": "markdownlint README.md",
        "lint:ts": "tsc --isolatedModules --noEmit",
        "lint:es": "eslint \"src/**/*.ts\" \"tests/**/*.spec.ts\" --ignore-pattern tests/fixtures/",
        "test": "npm-run-all lint test:unit",
        "test:pack": "bash -x scripts/npm-pack-testing.sh",
        "test:unit": "cross-env NODE_OPTIONS=\"--no-warnings --loader=ts-node/esm\" tap \"src/**/*.spec.ts\" \"tests/**/*.spec.ts\"",
        "typedoc": "bash scripts/typedoc.sh"
    },
    "repository": {
        "type": "git",
        "url": "git+https://github.com/wechaty/puppet.git"
    },
    "keywords": [
        "chatie",
        "wechaty",
        "wechat",
        "chatbot",
        "bot",
        "sdk"
    ],
    "author": "Huan LI <zixia@zixia.net>",
    "license": "Apache-2.0",
    "bugs": {
        "url": "https://github.com/wechaty/puppet/issues"
    },
    "homepage": "https://github.com/wechaty/puppet#readme",
    "devDependencies": {
        "@chatie/eslint-config": "^1.0.4",
        "@chatie/git-scripts": "^0.6.2",
        "@chatie/semver": "^0.4.7",
        "@chatie/tsconfig": "^4.6.2",
        "@swc/core": "1.3.44",
        "@swc/helpers": "^0.2.14",
        "@types/uuid": "^8.3.3",
        "nop": "^1.0.0",
        "regenerator-runtime": "^0.13.9",
        "rxjs": "^7.4.0",
        "tstest": "^1.0.1",
        "yocto-queue": "^1.0.0"
    },
    "dependencies": {
        "@alloc/quick-lru": "^5.2.0",
        "brolog": "^1.14.2",
        "clone-class": "^1.1.1",
        "file-box": "^1.4.13",
        "fp-ts": "^2.11.5",
        "gerror": "^1.0.16",
        "memory-card": "^1.1.2",
        "state-switch": "^1.7.1",
        "typed-emitter": "^1.5.0-from-event",
        "typesafe-actions": "^5.1.0",
        "uuid": "^8.3.2",
        "watchdog": "^0.9.2"
    },
    "files": [
        "dist/",
        "src/"
    ],
    "publishConfig": {
        "access": "public",
        "tag": "next"
    },
    "git": {
        "scripts": {
            "pre-push": "npx git-scripts-pre-push"
        }
    }
};
//# sourceMappingURL=package-json.js.map